use strict;
use warnings;
package Acme::Coinbase;

# ABSTRACT: Simple Coinbase API Test

1;

=head1 NAME

Acme::Coinbase -- Test coinbase client

=head1 SYNOPSIS

Example of a usage goes here, such as...

=head1 DESCRIPTION

What the object does.

=head1 METHODS

=head1 COPYRIGHT

Copyright (c) 2014 Josh Rabinowitz, All Rights Reserved.

=head1 AUTHORS

Josh Rabinowitz

=cut    

